local BeastCleaveSpellId = 118455;
local BeastCleaveName = GetSpellInfo(BeastCleaveSpellId);

local function SetDefaultPosistion(self)
	self:ClearAllPoints();
	self:SetPoint("LEFT",PlayerFrame,"RIGHT");
end

local function SetFrameSize(self, size)
	self:SetSize(size, size);
	_G[BCTOptions.size:GetName().."Text"]:SetText(size);
end

local function HideCooldownText(self, value)
	self:SetHideCountdownNumbers(value);
end

local BCTFrame = CreateFrame("Frame","BeastCleaveTracker",UIParent);
BCTFrame:Hide();
BCTFrame:SetMovable(true);
SetDefaultPosistion(BCTFrame);
BCTFrame:EnableMouse(false);
BCTFrame:RegisterForDrag("LeftButton");
BCTFrame:SetScript("OnDragStart", function(self) self:StartMoving(); end);
BCTFrame:SetScript("OnDragStop", function(self)	self:StopMovingOrSizing(); end);

BCTFrame.texture = BCTFrame:CreateTexture("BCTTexture","ARTWORK");
BCTFrame.texture:SetAllPoints(BCTFrame);
BCTFrame.texture:SetTexture("Interface\\Icons\\ability_hunter_sickem");

BCTFrame.cooldown = CreateFrame("Cooldown", "BCTCooldown", BCTFrame, "CooldownFrameTemplate");
BCTFrame.cooldown:SetAllPoints(BCTFrame);
BCTFrame.cooldown:SetDrawBling(false);
BCTFrame.cooldown:SetDrawSwipe(true);
BCTFrame.cooldown:SetDrawEdge(true);

local function onevent(self, event, ...)
	if(event == "ADDON_LOADED") then
		BCTFrame:UnregisterEvent("ADDON_LOADED");
		if(SBCTSaves == nil) then SBCTSaves = {}; end
		if(SBCTSaves.size == nil) then SBCTSaves.size = 30; end
		if(SBCTSaves.hideText == nil) then SBCTSaves.hideText = false; end
		SetFrameSize(BCTFrame, SBCTSaves.size);
		HideCooldownText(BCTFrame.cooldown, SBCTSaves.hideText);
		BCTOptions.size:SetValue(SBCTSaves.size);
		BCTOptions.hideText:SetChecked(SBCTSaves.hideText);
	elseif(event == "UNIT_AURA") then
		local u = ...;
		if(u == "pet") then
			local i = 1;
			local found = false;
			while(UnitBuff("pet",i)) do
				local n,_,_,_,_,d,e = UnitBuff("pet",i);
				if(n == BeastCleaveName) then
					found = true;
					BCTFrame:Show();
					BCTFrame.cooldown:SetCooldown(e-d,d);
					break;
				end
				i = i + 1;
			end
			if(not found and not BCTFrame.movingMode) then
				BCTFrame:Hide();
			end
		end
	end
end

local BCTOptions = CreateFrame("Frame","BCTOptions",UIParent);
BCTOptions.name = "Beast Cleave Tracker";
InterfaceOptions_AddCategory(BCTOptions);

BCTOptions.title = BCTOptions:CreateFontString();
BCTOptions.title:SetFontObject("GameFontNormalLarge");
BCTOptions.title:SetText("Simple Beast Cleave Tracker");
BCTOptions.title:SetPoint("TOPLEFT",BCTOptions, "TOPLEFT", 16, -16);

BCTOptions.move = CreateFrame("CheckButton", "BCTOptionsMove", BCTOptions, "UICheckButtonTemplate");
BCTOptions.move:SetPoint("TOPLEFT",BCTOptions.title, "BOTTOMLEFT");
_G[BCTOptions.move:GetName() .. "Text"]:SetText("Unlock frame for moving");
BCTOptions.move:SetScript("OnClick", function(self)	if(self:GetChecked()) then BCTFrame:Show(); BCTFrame:EnableMouse(true); BCTFrame.movingMode = true; else BCTFrame:EnableMouse(false); BCTFrame:Hide(); BCTFrame.movingMode = false; end end);

BCTOptions.moveReset = CreateFrame("Button", "BCTOptionsMoveReset", BCTOptions, "UIPanelButtonTemplate");
BCTOptions.moveReset:SetPoint("TOPLEFT",BCTOptions.move, "BOTTOMLEFT");
BCTOptions.moveReset:SetText("Reset to player frame");
BCTOptions.moveReset:SetWidth(200);
BCTOptions.moveReset:SetScript("OnClick", function() SetDefaultPosistion(BCTFrame); end);

BCTOptions.moveResetPet = CreateFrame("Button", "BCTOptionsMoveResetPet", BCTOptions, "UIPanelButtonTemplate");
BCTOptions.moveResetPet:SetPoint("TOPLEFT",BCTOptions.moveReset, "BOTTOMLEFT");
BCTOptions.moveResetPet:SetText("Reset to pet frame");
BCTOptions.moveResetPet:SetWidth(200);
BCTOptions.moveResetPet:SetScript("OnClick", function() BCTFrame:ClearAllPoints(); BCTFrame:SetPoint("LEFT",PetFrame,"RIGHT",-4,0); end);

BCTOptions.sizeText = BCTOptions:CreateFontString();
BCTOptions.sizeText:SetFontObject("GameFontNormal");
BCTOptions.sizeText:SetText("Size (default: 30)");
BCTOptions.sizeText:SetPoint("TOPLEFT", BCTOptions.moveResetPet, "BOTTOMLEFT", 0, -16);

BCTOptions.size = CreateFrame('Slider', 'BCTOptionsSize', BCTOptions, 'OptionsSliderTemplate');
BCTOptions.size:SetPoint("TOPLEFT",BCTOptions.sizeText, "BOTTOMLEFT", 0, -16);
BCTOptions.size:SetWidth(200);
BCTOptions.size:SetMinMaxValues(4, 80);
BCTOptions.size:SetValueStep(2);
BCTOptions.size:SetObeyStepOnDrag(true); 
_G[BCTOptions.size:GetName().."High"]:SetText(80);
_G[BCTOptions.size:GetName().."Low"]:SetText(4);
BCTOptions.size:SetScript("OnValueChanged", function(self, value) SBCTSaves.size = value; SetFrameSize(BCTFrame, SBCTSaves.size); end);

BCTOptions.hideText = CreateFrame('CheckButton', 'BCTOptionsHideText', BCTOptions, 'UICheckButtonTemplate');
BCTOptions.hideText:SetPoint("TOPLEFT",BCTOptions.size, "BOTTOMLEFT", 0, -16);
_G[BCTOptions.hideText:GetName() .. "Text"]:SetText("Hide cooldown text");
BCTOptions.hideText:SetScript("OnClick", function(self)	if(self:GetChecked()) then SBCTSaves.hideText = true; else SBCTSaves.hideText = false; end HideCooldownText(BCTFrame.cooldown, SBCTSaves.hideText) end);

BCTFrame:RegisterEvent("ADDON_LOADED");
BCTFrame:RegisterEvent("UNIT_AURA");
BCTFrame:SetScript("OnEvent", onevent);